@@ -2,15 +2,17 @@ use std::fmt::Display;
 use std::fs;
 use std::io::Read;
 use std::marker::PhantomData;
+use std::net::ToSocketAddrs;
 use std::path::PathBuf;
 use std::str::FromStr;
 use std::time::Duration;
 
+use ckb_jsonrpc_types as rpc_types;
 use ckb_sdk::{
     wallet::{zeroize_privkey, MasterPrivKey},
     Address, AddressPayload, AddressType, CodeHashIndex, HumanCapacity, NetworkType, OldAddress,
 };
-use ckb_types::{packed::OutPoint, prelude::*, H160, H256};
+use ckb_types::{core::ScriptHashType, packed::OutPoint, prelude::*, H160, H256};
 use clap::ArgMatches;
 use faster_hex::hex_decode;
 use url::Url;
@@ -252,6 +254,16 @@ impl std::ops::Deref for PrivkeyWrapper {
     }
 }
 
+pub struct HexFilePathParser;
+
+impl ArgParser<Vec<u8>> for HexFilePathParser {
+    fn parse(&self, input: &str) -> Result<Vec<u8>, String> {
+        let path: PathBuf = FilePathParser::new(true).parse(input)?;
+        let content = fs::read_to_string(&path).map_err(|err| err.to_string())?;
+        HexParser.parse(content.as_str())
+    }
+}
+
 pub struct PrivkeyPathParser;
 
 impl ArgParser<PrivkeyWrapper> for PrivkeyPathParser {
@@ -422,6 +434,7 @@ impl ArgParser<Address> for AddressParser {
             }
             if let Some(payload_option) = self.payload.as_ref() {
                 let payload = address.payload();
+                let is_new = address.is_new();
                 match payload_option {
                     AddressPayloadOption::Short(index_opt) => match payload {
                         AddressPayload::Short { index, .. } => {
@@ -437,13 +450,13 @@ impl ArgParser<Address> for AddressParser {
                         _ => {
                             return Err(format!(
                                 "Invalid address type: {:?}, expected: {:?}",
-                                payload.ty(),
+                                payload.ty(is_new),
                                 AddressType::Short,
                             ));
                         }
                     },
                     AddressPayloadOption::Full(code_hash_opt) => {
-                        if payload.ty() == AddressType::Short {
+                        if payload.ty(is_new) == AddressType::Short {
                             return Err(format!(
                                 "Unexpected address type: {:?}",
                                 AddressType::Short
@@ -452,21 +465,32 @@ impl ArgParser<Address> for AddressParser {
                         check_code_hash(payload, code_hash_opt.as_ref())?;
                     }
                     AddressPayloadOption::FullData(code_hash_opt) => {
-                        if payload.ty() != AddressType::FullData {
+                        if payload.ty(is_new) != AddressType::FullData
+                            && !(payload.ty(is_new) == AddressType::Full
+                                && payload.hash_type() != ScriptHashType::Type)
+                        {
                             return Err(format!(
-                                "Unexpected address type: {:?}, expected: {:?}",
-                                payload.ty(),
-                                AddressType::FullData
+                                "Unexpected address type: {:?}, expected: {:?} or ({:?} + {:?}/{:?})",
+                                payload.ty(is_new),
+                                AddressType::FullData,
+                                AddressType::Full,
+                                rpc_types::ScriptHashType::Data,
+                                rpc_types::ScriptHashType::Data1,
                             ));
                         }
                         check_code_hash(payload, code_hash_opt.as_ref())?;
                     }
                     AddressPayloadOption::FullType(code_hash_opt) => {
-                        if payload.ty() != AddressType::FullType {
+                        if payload.ty(is_new) != AddressType::FullType
+                            && !(payload.ty(is_new) == AddressType::Full
+                                && payload.hash_type() == ScriptHashType::Type)
+                        {
                             return Err(format!(
-                                "Unexpected address type: {:?}, expected: {:?}",
-                                payload.ty(),
-                                AddressType::FullType
+                                "Unexpected address type: {:?}, expected: {:?} or ({:?} + {:?})",
+                                payload.ty(is_new),
+                                AddressType::FullType,
+                                AddressType::Full,
+                                rpc_types::ScriptHashType::Type,
                             ));
                         }
                         check_code_hash(payload, code_hash_opt.as_ref())?;
@@ -482,7 +506,7 @@ impl ArgParser<Address> for AddressParser {
             .ok_or_else(|| format!("Invalid address prefix: {}", prefix))?;
         let old_address = OldAddress::from_input(network, input)?;
         let payload = AddressPayload::from_pubkey_hash(old_address.hash().clone());
-        Ok(Address::new(NetworkType::Testnet, payload))
+        Ok(Address::new(NetworkType::Testnet, payload, false))
     }
 }
 
@@ -538,9 +562,20 @@ impl ArgParser<Duration> for DurationParser {
     }
 }
 
+pub struct SocketParser;
+
+impl ArgParser<::std::net::SocketAddr> for SocketParser {
+    fn parse(&self, input: &str) -> Result<::std::net::SocketAddr, String> {
+        input
+            .to_socket_addrs()
+            .map_err(|e| e.to_string())
+            .and_then(|mut iter| iter.next().ok_or_else(|| "must socket format".to_string()))
+    }
+}
+
 #[cfg(test)]
 mod tests {
-    use ckb_types::{h160, h256};
+    use ckb_types::{bytes::Bytes, core::ScriptHashType, h160, h256, prelude::*};
     use std::net::IpAddr;
 
     use super::*;
@@ -601,7 +636,8 @@ mod tests {
                 AddressPayload::new_short(
                     CodeHashIndex::Sighash,
                     h160!("0xe22f7f385830a75e50ab7fc5fd4c35b134f1e84b")
-                )
+                ),
+                false,
             ))
         );
         // New address, lock-arg: 13e41d6F9292555916f17B4882a5477C01270142
@@ -612,7 +648,8 @@ mod tests {
                 AddressPayload::new_short(
                     CodeHashIndex::Sighash,
                     h160!("0x13e41d6F9292555916f17B4882a5477C01270142")
-                )
+                ),
+                false
             ))
         );
 
@@ -630,5 +667,21 @@ mod tests {
         assert!(AddressParser::default()
             .parse("kb1qyqp8eqad7ffy42ezmchkjyz54rhcqf8q9pqrn323p")
             .is_err());
+
+        // ckb2021 format address
+        let mut args = vec![0u8; 20];
+        faster_hex::hex_decode(b"b39bbc0b3673c7d36450bc14cfcdad2d559c6c64", &mut args).unwrap();
+        assert_eq!(
+            AddressParser::default().parse("ckb1qzda0cr08m85hc8jlnfp3zer7xulejywt49kt2rr0vthywaa50xwsqdnnw7qkdnnclfkg59uzn8umtfd2kwxceqxwquc4"),
+            Ok(Address::new(
+                NetworkType::Mainnet,
+                AddressPayload::new_full(
+                    ScriptHashType::Type,
+                    h256!("0x9bd7e06f3ecf4be0f2fcd2188b23f1b9fcc88e5d4b65a8637b17723bbda3cce8").pack(),
+                    Bytes::from(args),
+                ),
+                true,
+            ))
+        )
     }
 }
